/**
 *  Learnville Street Room
 *  @author Drakkos
 *  @started 08/10/2008
 *
 *  If you change this file, please also update it in LPC for Dummies.
 *
 */

// Tasks.h defines all the constants that go with making use of the 
// taskmaster handler.
#include <tasks.h>
#include "path.h"

inherit "/std/room/outside";

// Define the variable found to exist with class-wide scope.
int found;

void setup() {
  set_short ("simple village road");
  add_property ("determinate", "a ");
   
   // This sets the long description for the room for during the day.  
   // It works functionally identically to the standard set_long.
  set_day_long ("This path is lit by bright, beautiful daylight.  "
    "From the sun.  High above.  Because it's daytime, see?.\n");
    
   // This sets the long description for the room for during the night.  
   // It works functionally identically to the standard set_long. 
  set_night_long ("It's dark here, because it's nighttime.  As opposed "
    "to day time.  Do you understand what I mean?\n");

  // We can add items that are only visible during the day.  These 
  // are functionally identical to normal add_items.
  add_day_item ("bright beautiful daylight", "It illuminates the world "
    "around you!");
  add_day_item ("sun", "It burns our eyes, precious!");
  add_day_item ("daytime", "That's what it is.");
  add_day_item ("nighttime", "Don't worry, it'll probably be daytime "
    "forever.  No need to fret.");

  // We can add items that are only visible during the night.  These 
  // are functionally identical to normal add_items.
  
  add_night_item ("nighttime", "It's night, alright.  You can tell by all "
    "the dark around.");
  add_night_item ("dark", "You can't see the dark, because it's too dark.");
  add_night_item ("daytime", "Those halcyon hours are gone for good, or at "
    "least until the sun comes up again.");
  add_day_item ("sun", "There's no sun, because it's NIGHT.");

  add_item ("jagged rock", 
    ({
      "long", "This is a jagged rock.", 
      "searchable", "#search_rock",
      "position", "on the jagged rock",
      ({"kick", "punch"}), "Ow!  That stung!\n",
    })
  );

  // Sets up the random chats for daytime.  Functionally identical to the
  // normal room_chat code.
  
  room_day_chat ( ({ 120, 240, ({
    "The daytime is full of sunlight.",
    "You can see everything around you, because of the sun.",
    "The sun is shining in the sky.",
  })})); 

  // Sets up the random chats for nighttime.  Functionally identical to the
  // normal room_chat code.
  
  room_night_chat ( ({ 120, 240, ({
    "It is pitch black.  You are likely to be eaten by a grue.",
    "Was that a grue?  It sounded like a grue.",
    "If that's not a grue you can hear, it might be Vashta Nerada.",
  })}));   
  
  set_light (100);

  add_zone ("learnville");

  add_exit ("east", ROOMS + "market_southwest", "path");
  add_exit ("southwest", ROOMS + "street_02", "path");

}

int search_rock() {
  int success;
  
  if (found == 1) {
    tell_object (this_player(), "It looks like the rock has already "
      "been searched.\n");
    // When LPC gets to a return statement, it stops executing the code 
    // in the function and goes back to where it was before.
    return 1;
  }
  
  // This sends a request to the taskmaster.  The first parameter is the 
  // object against which we want to check the skills.  The second is 
  // the skill we want to check against.  The third is the bonus at which 
  // the checks may begin to succeed.  The last is Special - don't worry 
  // about it for now.
  success = TASKER->perform_task (this_player(), "adventuring.perception", 
    100, TM_FIXED);

  // The switch statement is essentially a compact if,else-if structure.  
  // We define a switch variable (in this case, success) and a series of 
  // cases that list the possible values that variable can have.  If the 
  // variable has that value, the code belonging to the case statement is
  // executed, and all code afterwards will be executed until it gets to a 
  // break statement.
  switch (success) {
    case AWARD:
      // This sends the TM message to the player.  The weird looking symbols 
      // define a colour code.
      tell_object (this_player(), "%^YELLOW%^%^BOLD%^You feel a little more "
        "perceptive.\n%^RESET%^");
    case SUCCEED:      
      found = 1;
    break;
    case FAIL:
        found = 0;
    break;
    // The default case is executed when there is no other matching case
    // value.
    default:
        tell_creator ("drakkos", "Yeah, I don't know what happened here.\n");
  }
    
  // If the found variable has a value, then they found something.
  if (found) {
    // Send a message to the player.
    tell_object (this_player(), "You have found a shiny Genuan cent!\n");
    // Adjust the player's money to the tune of one Genuan cent.
    this_player()->adjust_money (1, "Genuan cent");
  }
  else {
    tell_object (this_player(), "You don't find anything in the rock.\n");
  }  
 
  return 1;
}

void reset() {
  ::reset();

  found = 0;
}